# GitHub Utils API

An API library to comunicate with some admin points of the Github API not covered by PyGithub

## How to use this plugin

 1. Install this library using pip `pip install github-utils-api`
 2. Import in your code `from githubutilsapi import GithubUtilsApi`
 3. Create and automate!!

## How to contribute
 1. Fork this project
 2. Install required software Python3
 3. Make your changes
 4. Remeber to generate documented methods
 5. Test your changes and create the pull request

## License
This work is licensed under the terms of the MIT license.
For a copy, see <https://opensource.org/licenses/MIT>.
